use actix_web::{web, HttpRequest, HttpResponse, Responder};
use serde::{Deserialize, Serialize};
use crate::repositories;
use crate::repositories::session::get_username_from_session;

#[derive(Deserialize, Clone)]
pub struct AuthenticateRequest {
    user_id: i64,
    auth_date: i64,
    username: String,
    first_name: String,
    last_name: String,
    photo_url: String,
}

#[derive(Serialize)]
pub struct AuthenticateResponse {
    session_id: String,
}

pub async fn authenticate(req: web::Json<AuthenticateRequest>) -> impl Responder {
    let session_id = repositories::session::authenticate_session(
        req.clone().user_id,
        req.clone().auth_date,
        req.clone().username,
        req.clone().first_name,
        req.clone().last_name,
        req.clone().photo_url
    );
    let resp = AuthenticateResponse { session_id };
    HttpResponse::Ok().json(resp)
}

#[derive(Serialize)]
pub struct GetUsernameResponse {
    username: Option<String>,
}

pub async fn get_username(req: HttpRequest) -> impl Responder {
    if let Some(session_cookie) = req.cookie("session") {
        let username = get_username_from_session(session_cookie.value().to_string());
        return HttpResponse::Ok().json(GetUsernameResponse { username })
    }
    HttpResponse::Unauthorized().into()
}