pub mod db;
pub mod models;
pub mod schema;
pub mod repositories;
pub mod api;

use actix_web::{web, App, HttpServer, Responder};
use api::{issue, session};
use crate::api::comment;

#[actix_web::main]
async fn main() -> std::io::Result<()> {
    HttpServer::new(|| {
        App::new()
            .service(
                web::scope("/issues")
                    .route("/create", web::post().to(issue::add_issue))
                    .route("/list", web::get().to(issue::list_issues))
                    .route("/paragraphs", web::get().to(issue::get_paragraphs))
                    .route("/vote", web::post().to(issue::vote_issue))
                    .route("/get_vote", web::get().to(issue::get_user_vote))
                    .route("/comments", web::get().to(comment::get_comments))
            )
            .service(
                web::scope("/sessions")
                    .route("/authenticate", web::post().to(session::authenticate))
                    .route("/get_username", web::get().to(session::get_username))
            )
    })
        .bind(("127.0.0.1", 8080))?
        .run()
        .await
}
