use diesel::{OptionalExtension, QueryDsl, RunQueryDsl, SelectableHelper};
use diesel::ExpressionMethods;
use uuid::Uuid;
use crate::db::db::establish_connection;
use crate::models::models::{NewSession, Session};
use crate::schema::sessions;
use crate::schema::sessions::dsl::sessions as sessions_dsl;
use crate::schema::sessions::session_id;

pub fn get_session(sess_id: String) -> Option<Session> {
    let connection = &mut establish_connection();
    sessions_dsl
        .filter(session_id.eq(sess_id))
        .select(Session::as_select())
        .first(connection)
        .optional()
        .expect("Error loading session")
}

pub fn authenticate_session(user_id: i64, auth_date: i64, username: String, first_name: String, last_name: String, photo_url: String) -> String {
    let sess_id: Uuid = Uuid::new_v4();

    let connection = &mut establish_connection();
    let new_session = NewSession {
        user_id: Some(user_id),
        session_id: sess_id.clone().to_string(),
        auth_date,
        username: Some(username),
        first_name: Some(first_name),
        last_name: Some(last_name),
        photo_url: Some(photo_url),
    };

    let result = diesel::insert_into(sessions::table)
        .values(&new_session)
        .returning(Session::as_select())
        .get_result(connection)
        .unwrap();

    result.session_id
}

pub fn get_user_id(sess_id: String) -> Option<i64> {
    let connection = &mut establish_connection();
    let user_id: Option<i64> = sessions::table
        .filter(session_id.eq(sess_id))
        .limit(1)
        .select(sessions::user_id)
        .get_result(connection)
        .optional()
        .unwrap_or(None);

    user_id
}

pub fn get_username_from_session(sess_id: String) -> Option<String> {
    let connection = &mut establish_connection();
    let username = sessions::table
        .filter(sessions::session_id.eq(sess_id))
        .limit(1)
        .select(sessions::username)
        .get_result(connection)
        .unwrap_or_default();

    username
}
